from bluer_objects.README.items import ImageItems

from bluer_sbc.README.design import design_doc
from bluer_sbc.README.designs.swallow.consts import swallow_assets2
from bluer_sbc.README.designs.swallow import image_template, latest_version
from bluer_sbc.README.designs.swallow.parts import parts

docs = [
    design_doc(
        "swallow/v1",
        ImageItems(
            {
                f"{swallow_assets2}/20250609_164433.jpg": "",
                f"{swallow_assets2}/20250614_114954.jpg": "",
                f"{swallow_assets2}/20250615_192339.jpg": "",
            }
        ),
        parts,
    )
] + [
    design_doc(
        f"swallow/v{version}",
        ImageItems(
            {
                image_template(version).format(
                    f"{index+1:02}.jpg",
                ): ""
                for index in range(6)
            }
        ),
        parts,
    )
    for version in range(2, latest_version)
]



from bluer_objects import README
from bluer_objects.README.items import ImageItems
from bluer_objects.README.consts import assets_url

from bluer_sbc.README.design import design_doc


assets2 = assets_url(
    suffix="shelter",
    volume=2,
)

image_template = assets2 + "/{}?raw=true"


marquee = README.Items(
    [
        {
            "name": "shelter",
            "marquee": f"{assets2}/20251104_000755.jpg",
            "url": "./bluer_sbc/docs/shelter",
        }
    ]
)

items = ImageItems(
    {image_template.format(f"{index+1:02}.png"): "" for index in range(4)}
) + ImageItems(
    {
        f"{assets2}/20251005_180841.jpg": "",
        f"{assets2}/20251006_181432.jpg": "",
        f"{assets2}/20251006_181509.jpg": "",
        f"{assets2}/20251006_181554.jpg": "",
        f"{assets2}/20251028_113245.jpg": "",
        f"{assets2}/20251103_182323.jpg": "",
        f"{assets2}/20251104_000755.jpg": "",
        f"{assets2}/20251109_000501.jpg": "",
        f"{assets2}/20251109_000641.jpg": "",
        f"{assets2}/20251109_002124.jpg": "",
        f"{assets2}/20251109_002639.jpg": "",
        f"{assets2}/20251124_094744.jpg": "",
        f"{assets2}/20251202_101949.jpg": "",
        f"{assets2}/20251202_102912.jpg": "",
    }
)

parts = {
    "220VAC-dimmer": "",
    "resistance-heating-wire": "1.59 kΩ",
    "ceramic-terminal": "",
    "mountable-digital-thermometer": "",
}


docs = [
    design_doc(
        "shelter",
        items,
        parts,
        own_folder=True,
        parts_reference="../parts",
    ),
    {
        "path": "../docs/shelter/parts-v1.md",
    },
]



from bluer_objects.README.items import ImageItems

from bluer_sbc.README.design import design_doc
from bluer_sbc.README.designs.swallow_head import image_template, latest_version
from bluer_sbc.README.designs.swallow_head.parts import parts

docs = [
    design_doc(
        f"swallow-head/v{version}",
        ImageItems(
            {
                image_template(version).format(
                    f"{index+1:02}.jpg",
                ): ""
                for index in range(6)
            }
        ),
        parts,
    )
    for version in range(1, latest_version)
]



from bluer_objects import README
from bluer_objects.README.items import ImageItems

from bluer_sbc.README.designs.consts import assets2
from bluer_sbc.README.designs import pwm_generator, battery_bus
from bluer_sbc.README.design import design_doc

image_template = assets2 + "nafha/{}?raw=true"

marquee = README.Items(
    [
        {
            "name": "nafha",
            "marquee": image_template.format("01.png"),
            "url": "./bluer_sbc/docs/nafha",
        }
    ]
)

items = ImageItems(
    {
        image_template.format(f"{filename}"): ""
        for filename in [f"{index+1:02}.png" for index in range(4)]
        + [
            "20251028_123428.jpg",
            "20251028_123438.jpg",
            "20251103_215221.jpg",
            "20251103_215248.jpg",
            "20251103_215253.jpg",
            "20251103_215257.jpg",
            "20251103_215301.jpg",
            "20251103_215319.jpg",
            "20251116_224456.jpg",
            "20251124_094940.jpg",
            "20251125_203403.jpg",
        ]
    },
)

parts = {
    **battery_bus.parts,
    **pwm_generator.parts,
    **{
        "heater-element": "12 V, 4.5 Ω, 32 w",
    },
}

docs = [
    design_doc(
        "nafha",
        items,
        parts,
        own_folder=True,
        parts_reference="../parts",
    ),
    {
        "path": "../docs/nafha/parts-v1.md",
    },
    {
        "path": "../docs/nafha/parts-v2.md",
    },
]



from bluer_objects import markdown

from bluer_sbc.parts.db import db_of_parts

docs = [
    {
        "path": "../docs/parts",
        "macros": {
            "parts_list:::": db_of_parts.README,
            "parts_images:::": markdown.generate_table(
                db_of_parts.as_images(
                    {part.name: "" for part in db_of_parts},
                    reference="../parts",
                ),
                cols=10,
                log=False,
            ),
        },
    }
] + [
    {
        "path": part.filename(create=True),
        "macros": {
            "info:::": part.README(db_of_parts.url_prefix),
        },
    }
    for part_name, part in db_of_parts.items()
    if part_name != "template"
]



from bluer_sbc.README.designs import (
    adapter_bus,
    battery_bus,
    nafha,
    pwm_generator,
    regulated_bus,
    shelter,
    template,
    ultrasonic_sensor_tester,
)
from bluer_sbc.README.designs.cheshmak import docs as cheshmak
from bluer_sbc.README.designs.swallow import docs as swallow
from bluer_sbc.README.designs.swallow_head import docs as swallow_head


docs = (
    adapter_bus.docs
    + battery_bus.docs
    + cheshmak.docs
    + nafha.docs
    + pwm_generator.docs
    + regulated_bus.docs
    + shelter.docs
    + swallow_head.docs
    + swallow.docs
    + ultrasonic_sensor_tester.docs
    + template.docs
)



from bluer_sbc.README.design import design_doc
from bluer_sbc.README.designs.cheshmak import operation, parts, validations
from bluer_sbc.README.designs.cheshmak.items import items
from bluer_sbc.README.designs.cheshmak.body import docs as body


docs = (
    [
        design_doc(
            "cheshmak",
            items,
            own_folder=True,
        ),
    ]
    + body.docs
    + operation.docs
    + parts.docs
    + validations.docs
)



from bluer_objects.README.items import ImageItems

from bluer_sbc.README.design import design_doc
from bluer_sbc.README.designs.swallow import image_template
from bluer_sbc.README.designs.swallow.parts import parts
from bluer_sbc.README.designs.swallow import history
from bluer_sbc.README.designs.swallow import latest_version

items = ImageItems(
    {
        image_template(latest_version).format(f"{index+1:02}.jpg"): ""
        for index in range(6)
    }
)

docs = [
    design_doc(
        "swallow",
        items,
        parts,
        own_folder=True,
        parts_reference="../parts",
    )
] + history.docs
